@@ -11,11 +11,11 @@ URL::Normalize - Normalize/optimize URLs.
 
 =head1 VERSION
 
-Version 0.31
+Version 0.32
 
 =cut
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 =head1 SYNOPSIS
 
@@ -35,7 +35,7 @@ our $VERSION = '0.31';
 =head1 DESCRIPTION
 
 This is NOT a perfect solution. If you normalize a URL using all the methods in
-this module, there is a high probability that the URL will "stop working". This
+this module, there is a high probability that the URL will stop "working." This
 is merely a helper module for those of you who wants to either normalize a URL
 using only a few of the safer methods, and/or for those of you who wants to
 generate a unique "ID" from any given URL.
@@ -81,7 +81,7 @@ You can also send in just the path:
     my $normalizer = URL::Normalize->new( '/some/path' );
 
 The latter is not recommended, however, so you should look into L<URI>'s
-C<new_abs> to create "real" URLs before you send them to URL::Normalize.
+C<new_abs> to create absolute URLs before you use them with URL::Normalize.
 
 =cut
 
@@ -110,14 +110,18 @@ normalization methods.
 
 has 'url' => (
     isa      => 'Str',
-    is       => 'rw',
+    is       => 'ro',
     required => 1,
     writer   => '_set_url',
 );
 
 has 'dir_index_regexps' => (
+    traits  => [ 'Array' ],
     isa     => 'ArrayRef[Str]',
     is      => 'rw',
+    handles => {
+        'add_directory_index_regexp' => 'push',
+    },
     default => sub {
         [
             '/default\.aspx?',
@@ -130,8 +134,12 @@ has 'dir_index_regexps' => (
 );
 
 has 'social_query_params' => (
+    traits  => [ 'Array' ],
     isa     => 'ArrayRef[Str]',
     is      => 'rw',
+    handles => {
+        'add_social_query_param' => 'push',
+    },
     default => sub {
         [
             'ncid',
@@ -524,7 +532,7 @@ sub remove_empty_query {
 
 Removes the fragment from the URL, but only if they are at the end of the URL.
 
-For example "http://www.example.com/#foo" will be translated to
+For example C<http://www.example.com/#foo> will be translated to
 C<http://www.example.com/>, but C<http://www.example.com/#foo/bar> will stay the
 same.
 
